Tutorial
========

.. include:: ../README.rst
   :start-after: _tutorial_start:
   :end-before:  _tutorial_end:

.. include:: ../README.rst
   :start-after: _appendix_start:
   :end-before:  _appendix_end:
